# Toolchain icestorm class

import requests
from os import rename
from os.path import isdir, join

from ..installer import Installer


class IcestormInstaller(Installer):

    def __init__(self):
        self.package = 'toolchain-icestorm'
        self.name = 'toolchain-icestorm'
        self.platform = self._get_platform()
        self.version = self._get_version()
        self.extension = 'tar.gz'

    def install(self):
        super(IcestormInstaller, self).install()

        # Rename unpacked dir to package dir
        unpack_dir = join(self.packages_dir, self.name)
        package_dir = join(self.packages_dir, self.package)
        if isdir(unpack_dir):
            rename(unpack_dir, package_dir)

    def _get_download_url(self):
        url = '{0}/0.{1}/{2}'.format(
            'https://github.com/bqlabs/toolchain-icestorm/releases/download',
            self.version,
            self._get_package_name())
        return url

    def _get_package_name(self):
        name = '{0}-{1}-{2}.{3}'.format(
            self.name,
            self.platform,
            self.version,
            self.extension)
        return name

    def _get_version(self):
        releases_url = 'https://api.github.com/repos/bqlabs/toolchain-icestorm/releases/latest'
        response = requests.get(releases_url)
        releases = response.json()
        version = releases['tag_name'].split('.')[1]  # 0.X -> X
        return version



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import click
import subprocess

from .util import get_systype
from .installer import Installer
from .packages.icestorm import IcestormInstaller
from .packages.scons import SconsInstaller
from .packages.rules import RulesInstaller

# Give the priority to the packages installed by apio
os.environ['PATH'] = (
    os.path.join(Installer.packages_dir, 'toolchain-icestorm', 'bin') + ":" +
    os.environ['PATH'])

scons_path = os.path.join(Installer.packages_dir, 'tool-scons', 'script', 'scons')


@click.group()
@click.version_option()
def cli():
    """
    """


@cli.command('debug')
def debug():
    print('Platform: ' + get_systype())


@cli.command('install')
def install():
    IcestormInstaller().install()
    SconsInstaller().install()
    RulesInstaller().install()


@cli.command('uninstall')
def uninstall():
    key = raw_input('Are you sure? [Y/N]: ')
    if key == 'y' or key == 'Y':
        IcestormInstaller().uninstall()
        SconsInstaller().uninstall()
        RulesInstaller().uninstall()


@cli.command('clean')
def clean():
    subprocess.call(['python', scons_path, '-c'])


@cli.command('build')
def build():
    subprocess.call(['python', scons_path])


@cli.command('upload')
def upload():
    subprocess.call(['python', scons_path, 'upload'])


@cli.command('time')
def time():
    subprocess.call(['python', scons_path, 'time'])


@cli.command('sim')
def sim():
    subprocess.call(['python', scons_path, 'sim'])



# Rules icestick class

import subprocess

from os.path import join, dirname, isfile


class RulesInstaller(object):

    rules_local_path = join(dirname(__file__), '80-icestick.rules')
    rules_system_path = '/etc/udev/rules.d/80-icestick.rules'

    def install(self):
        print('Install icestick.rules')
        if not isfile(self.rules_system_path):
            subprocess.call(['sudo', 'cp', self.rules_local_path, self.rules_system_path])
        else:
            print('Package icestick.rules is already the newest version')

    def uninstall(self):
        if isfile(self.rules_system_path):
            print('Uninstall package icestick.rules')
            subprocess.call(['sudo', 'rm', self.rules_system_path])
        else:
            print('Package icestick.rules is not installed')



# -*- coding: utf-8 -*-

from setuptools import setup

setup(
    name='apio',
    author='Jesús Arroyo Torrens',
    email='jesus.arroyo@bq.com',
    version='0.0.4.1',
    packages=['apio'],
    package_data={
        'apio': ['packages/*']
    },
    install_requires=[
        'click',
        'requests'
    ],
    entry_points={
        'console_scripts': ['apio=apio:cli']
    },
    classifiers=['Development Status :: 1 - Planning',
                 'Environment :: Console',
                 'Intended Audience :: Developers',
                 'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',
                 'Programming Language :: Python']
)
